hextime

package module
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2022 License: BSD-2-Clause-Views Imports: 2 Imported by: 0

README

go-hextime - a Go port of hextime

EXAMPLE

$ hextime
e_40_9

DOWNLOAD

https://github.com/mcandre/go-hextime/releases

DOCUMENTATION

https://godoc.org/github.com/mcandre/go-hextime

RUNTIME REQUIREMENTS

(None)

INSTALL FROM SOURCE

$ go install github.com/mcandre/go-hextime/cmd/hextime@latest

CONTRIBUTING

For more information on developing go-hextime itself, see DEVELOPMENT.md.

Documentation

Overview

Package hextime provides conversion functions for formatting time in hexadecimal.

Index

Constants

This section is empty.

Variables

var Version = "0.0.3"

Version is semver.

Functions

func Hex

func Hex(t time.Time) string

Hex formats the given time into a hexadecimal notation.

func Hextime

func Hextime() string

Hextime formats the current time into a hexadecimal notation.

Types

This section is empty.

Directories

Path Synopsis
cmd
hextime command
Package main provides a hextime executable.
Package main provides a hextime executable.

Jump to