hextime

package module
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2018 License: BSD-2-Clause-Views Imports: 2 Imported by: 0

README

go-hextime - a Go port of hextime

EXAMPLE

$ hextime
e_40_9

DOWNLOAD

https://github.com/mcandre/go-hextime/releases

DOCUMENTATION

https://godoc.org/github.com/mcandre/go-hextime

RUNTIME REQUIREMENTS

(None)

BUILDTIME REQUIREMENTS

  • Go 1.9+
  • Docker
  • Mage (e.g., go get github.com/magefile/mage)
  • goimports (e.g. go get golang.org/x/tools/cmd/goimports)
  • golint (e.g. go get github.com/golang/lint/golint)
  • errcheck (e.g. go get github.com/kisielk/errcheck)
  • nakedret (e.g. go get github.com/alexkohler/nakedret)
  • goxcart (e.g., github.com/mcandre/goxcart/...)
  • zipc (e.g. go get github.com/mcandre/zipc/...)

INSTALL FROM REMOTE GIT REPOSITORY

$ go get github.com/mcandre/go-hextime/...

(Yes, include the ellipsis as well, it's the magic Go syntax for downloading, building, and installing all components of a package, including any libraries and command line tools.)

INSTALL FROM LOCAL GIT REPOSITORY

$ mkdir -p $GOPATH/src/github.com/mcandre
$ git clone https://github.com/mcandre/go-hextime.git $GOPATH/src/github.com/mcandre/go-hextime
$ cd "$GOPATH/src/github.com/mcandre/go-hextime"
$ git submodule update --init --recursive
$ go install ./...

TEST

$ mage test

PORT

$ mage port

LINT

Keep the code tidy:

$ mage lint

Documentation

Overview

Package hextime provides conversion functions for formatting time in hexadecimal.

Index

Constants

This section is empty.

Variables

var Version = "0.0.2"

Version is semver.

Functions

func Hex

func Hex(t time.Time) string

Hex formats the given time into a hexadecimal notation.

func Hextime

func Hextime() string

Hextime formats the current time into a hexadecimal notation.

Types

This section is empty.

Directories

Path Synopsis
cmd
hextime command
Package main provides a hextime executable.
Package main provides a hextime executable.

Jump to